@@ -30,6 +30,16 @@ def remove_unneeded_f_strings(
 
         # ASTs start at line 1, but we expect our lists to start at 0
         line_no = unneeded_f_string.lineno - 1
+
+        # A safety check, we should never remove a character that's not 'f'
+        # This can occur during the following line of python code, for example:
+        #
+        # a = 'hi' f'hello'
+        #
+        # unfortunately, python combines this ^ into one Constant in the AST
+        if content_list[line_no][loc] != 'f':
+            continue
+
         content_list[line_no] = content_list[line_no][:loc] + \
             content_list[line_no][loc + 1:]
     return '\n'.join(content_list)
